enum Transports { WEB_SOCKET, POLLING }

class SocketOptions {
  final String uri;
  final int timeout;
  final Map<String, String> query;

  ///Enable debug logging
  final bool enableLogging;

  ///List of transport names.
  List<Transports> transports;


  ///Namespace parameter
  String nameSpace;

  ///Path parameter if socket.io runs on a different endpoint
  String path;
  
  SocketOptions(this.uri,
      {this.query: const {},
      this.enableLogging: false,
      this.timeout: -1,
      this.transports: const [Transports.WEB_SOCKET, Transports.POLLING],
      this.nameSpace = "/",
      this.path = '/socket.io'})
      : assert(nameSpace.startsWith("/"),
            "Namespace must be a non null string and should start with a '/'");

  Map asMap() {
    return {
      "uri": uri,
      "query": query,
      "path": path,
      "enableLogging": enableLogging,
      "namespace": nameSpace,
      "transports": transports.map((Transports t) {
        return {
          Transports.WEB_SOCKET: "websocket",
          Transports.POLLING: "polling"
        }[t];
      }).toList(),
      "timeout": timeout
    };
  }
}
